"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandFactory = void 0;
const node_util_1 = require("node:util");
const node_assert_1 = require("node:assert");
const utility_1 = require("@jfrog-pipelines/utility");
const NodeStatsCleanupHandler_1 = require("./feature/node/NodeStatsCleanupHandler");
const NodeStatsCleanupCommand_1 = require("./driving/command/NodeStatsCleanupCommand");
const NodeStatsCheckCommand_1 = require("./driving/command/NodeStatsCheckCommand");
const NodeStatsCheckHandler_1 = require("./feature/node/NodeStatsCheckHandler");
const ProcessNodePoolCommand_1 = require("./driving/command/ProcessNodePoolCommand");
const ProcessNodePoolHandler_1 = require("./feature/nodepool/ProcessNodePoolHandler");
const CreateStaticNodeCommand_1 = require("./driving/command/CreateStaticNodeCommand");
const CreateStaticNodeHandler_1 = require("./feature/node/CreateStaticNodeHandler");
class CommandFactory {
    static getHandler(serviceMetaData, message) {
        const payload = message.payload;
        switch (payload.eventType) {
            case utility_1.Actor.NODE_STATS_DELETE: {
                return new NodeStatsCleanupHandler_1.NodeStatsCleanupHandler(new NodeStatsCleanupCommand_1.NodeStatsCleanupCommand());
            }
            case utility_1.Actor.NODE_STATS_CHECK: {
                return new NodeStatsCheckHandler_1.NodeStatsCheckHandler(new NodeStatsCheckCommand_1.NodeStatsCheckCommand());
            }
            case utility_1.Actor.NODE_POOL_PROCESSING: {
                return new ProcessNodePoolHandler_1.ProcessNodePoolHandler(ProcessNodePoolCommand_1.ProcessNodePoolCommand.create(payload.payload?.id), serviceMetaData);
            }
            case utility_1.Actor.CREATE_NODE: {
                return new CreateStaticNodeHandler_1.CreateStaticNodeHandler(CreateStaticNodeCommand_1.CreateStaticNodeCommand.create(payload.payload?.id));
            }
            default: {
                throw new node_assert_1.AssertionError({ message: `No Suitable handler found for message ${(0, node_util_1.inspect)(message)}` });
            }
        }
    }
}
exports.CommandFactory = CommandFactory;
//# sourceMappingURL=CommandFactory.js.map