"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodePoolWorker = void 0;
const node_util_1 = require("node:util");
const node_assert_1 = require("node:assert");
const logger_1 = require("@jfrog-pipelines/logger");
const CommandFactory_1 = require("./CommandFactory");
class NodePoolWorker {
    constructor(serviceMetaData) {
        this.serviceMetaData = serviceMetaData;
        this.logger = logger_1.LoggerFactory.getLogger('nodePoolWorker');
    }
    async process(message) {
        try {
            this.logger.info(`Processing command`, (0, node_util_1.inspect)(message));
            if (!message?.payload) {
                throw new node_assert_1.AssertionError({ message: 'Payload is required property, received undefined or null' });
            }
            const handler = CommandFactory_1.CommandFactory.getHandler(this.serviceMetaData, message);
            await handler.handle();
        }
        catch (error) {
            this.errorHandler(error);
        }
    }
    errorHandler(error) {
        const errorMessage = (0, node_util_1.inspect)(error);
        if (error instanceof node_assert_1.AssertionError) {
            this.logger.warn(errorMessage);
            return;
        }
        this.logger.error(errorMessage);
    }
}
exports.NodePoolWorker = NodePoolWorker;
//# sourceMappingURL=NodePoolWorker.js.map