"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const microservice_1 = require("@jfrog-pipelines/microservice");
const utility_1 = require("@jfrog-pipelines/utility");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const ServerDefinitionV1_1 = require("./driving/rest/ServerDefinitionV1");
const NodeVersionUpgradeInitializer_1 = require("./feature/NodeVersionUpgradeInitializer");
const NodePoolWorker_1 = require("./NodePoolWorker");
const logLevel = 'info';
const serviceEnum = 11;
const serviceDetails = utility_1.ServiceMeta[serviceEnum];
const options = {
    enum: serviceEnum,
    initializers: [new microservice_1.AmqpClientInitializer(), new NodeVersionUpgradeInitializer_1.NodeVersionUpgradeInitializer()],
    healthChecks: [],
    logLevel: logLevel,
    models: [data_access_layer_1.BuildPlaneMessage, data_access_layer_1.Lock, data_access_layer_1.Node, data_access_layer_1.NodePool, data_access_layer_1.SystemConfig, data_access_layer_1.NodeStats, data_access_layer_1.BuildPlaneImages, data_access_layer_1.NodeConsole],
    productHome: process.env.APP_CONFIG_PATH,
    validator: new microservice_1.DefaultApplicationValidator([], []),
    isAccessEnabled: true,
    serverDefinition: new ServerDefinitionV1_1.ServerDefinitionV1(serviceDetails),
    cacheContext: {
        defaultCacheStore: "MEMORY",
        enableInMemoryCache: true,
        enableRedisCache: false
    }
};
async function startApp() {
    const app = new microservice_1.Application(options, microservice_1.applicationContext);
    const poolWorker = new NodePoolWorker_1.NodePoolWorker(serviceDetails);
    await app.listen(utility_1.NODEPOOL_SERVICE_MESSAGE_KEY, poolWorker);
}
void startApp();
//# sourceMappingURL=app.js.map