"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MachineImageValidator = void 0;
const errors_1 = require("@jfrog-pipelines/errors");
const metadata_1 = require("@jfrog-pipelines/metadata");
const utility_1 = require("@jfrog-pipelines/utility");
class MachineImageValidator {
    static validateCreate(buildPlaneImage) {
        this.validateNodeMetadataProperties(buildPlaneImage);
        this.validateMasterIntegrationForCreate(buildPlaneImage);
    }
    static validateMasterIntegrationForUpdate(masterIntegrationId, metadataPropertyBag) {
        const masterIntegration = this.masterIntegration.getMasterIntegrations(undefined, masterIntegrationId.toString());
        if (masterIntegration.length === 0) {
            throw new errors_1.BadRequestError(`MasterIntegration not found for id: ${masterIntegrationId}`);
        }
        this.validateMasterIntegrationForGcloud(metadataPropertyBag, masterIntegration[0]);
    }
    static validateNodeMetadataProperties(buildPlaneImage) {
        if (!metadata_1.NodeMetadata.supportedArchitectures.includes(buildPlaneImage.architecture)) {
            throw new errors_1.BadRequestError(`Invalid parameter :architecture should be ${metadata_1.NodeMetadata.supportedArchitectures.join(',')}`);
        }
        const supportedOs = (0, utility_1.keys)(metadata_1.NodeMetadata.supportedOsAndFamilyMap);
        if (!supportedOs.includes(buildPlaneImage.operatingSystem)) {
            throw new errors_1.BadRequestError(`Invalid parameter :operatingSystem should be ${supportedOs.join(',')}`);
        }
    }
    static validateMasterIntegrationForCreate(buildPlaneImage) {
        const masterIntegration = this.masterIntegration.getMasterIntegrations(undefined, buildPlaneImage.masterIntegrationId.toString());
        if (masterIntegration.length === 0) {
            throw new errors_1.BadRequestError(`MasterIntegration not found for id: ${buildPlaneImage.masterIntegrationId}`);
        }
        if (!masterIntegration[0].isEnabled) {
            throw new errors_1.BadRequestError(`MasterIntegration disabled for id: ${buildPlaneImage.masterIntegrationId}`);
        }
        this.validateMasterIntegrationForGcloud(buildPlaneImage.metadataPropertyBag, masterIntegration[0]);
    }
    static validateMasterIntegrationForGcloud(imageMetadataPropertyBag, masterIntegration) {
        if (masterIntegration.name === 'gcloudKey' && this.isInvalidGcloudMetadataBag(imageMetadataPropertyBag)) {
            throw new errors_1.BadRequestError(`metadataPropertyBag.imageName and metadataPropertyBag.projectName are required for cloud provider: ${masterIntegration.displayName}`);
        }
    }
    static isInvalidGcloudMetadataBag(imageMetadataPropertyBag) {
        const metadataPropertyBag = imageMetadataPropertyBag;
        return ((0, utility_1.isEmpty)(metadataPropertyBag) || (0, utility_1.isEmpty)(metadataPropertyBag.imageName) || (0, utility_1.isEmpty)(metadataPropertyBag.projectName));
    }
}
exports.MachineImageValidator = MachineImageValidator;
MachineImageValidator.masterIntegration = new metadata_1.MasterIntegrations();
//# sourceMappingURL=MachineImageValidator.js.map