"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeConsoleLedgerService = void 0;
const node_util_1 = require("node:util");
const utility_1 = require("@jfrog-pipelines/utility");
const configuration_1 = require("@jfrog-pipelines/configuration");
const logger_1 = require("@jfrog-pipelines/logger");
const repository_1 = require("./repository");
class NodeConsoleLedgerService {
    constructor() {
        this.properties = configuration_1.ConfigFactory.config;
        this.logger = logger_1.LoggerFactory.getLogger('NodeConsoleLedgerService');
        this.nodeConsoleRepository = repository_1.NodeConsoleFactory.getRepository(this.properties.isSaaS);
        this.startTimeInMs = Date.now() * 1000;
        const processStartTime = process.hrtime();
        this.processStartTimeInMicroSec = processStartTime[0] * 1e6 + processStartTime[1] / 1e3;
    }
    async push(message, nodeId) {
        const newNodeConsole = this.createNodeConsole(message, nodeId);
        await this.insertNodeConsole(newNodeConsole);
    }
    async getById(nodeId) {
        try {
            return await this.nodeConsoleRepository.getById(nodeId);
        }
        catch (error) {
            this.logger.warn(`failed to fetch node consoles for nodeId ${nodeId} due to error ${(0, node_util_1.inspect)(error)}`);
            return [];
        }
    }
    createNodeConsole(message, nodeId) {
        const consoleId = (0, utility_1.uuidv5)(new Date().toISOString(), utility_1.uuidv5.URL);
        return {
            nodeId: nodeId,
            consoleId: consoleId,
            parentConsoleId: 'root',
            type: 'msg',
            timestamp: this.getTimeStamp(),
            message: message,
            isShown: true
        };
    }
    async insertNodeConsole(nodeConsole) {
        try {
            await (Array.isArray(nodeConsole)
                ? this.nodeConsoleRepository.createBulk(nodeConsole)
                : this.nodeConsoleRepository.create(nodeConsole));
        }
        catch (error) {
            this.logger.warn(`Failed to insert node console ${(0, node_util_1.inspect)(nodeConsole)} due to ${(0, node_util_1.inspect)(error)}`);
        }
    }
    async deleteByNodeId(nodeId) {
        try {
            await this.nodeConsoleRepository.deleteByNodeId(nodeId);
        }
        catch (error) {
            this.logger.warn(`Failed to delete node consoles for nodeId=${nodeId} due to ${(0, node_util_1.inspect)(error)}`);
        }
    }
    getTimeStamp() {
        const currentProcessTime = process.hrtime();
        return Math.round(this.startTimeInMs + (currentProcessTime[0] * 1e6 + currentProcessTime[1] / 1e3) - this.processStartTimeInMicroSec);
    }
}
exports.NodeConsoleLedgerService = NodeConsoleLedgerService;
//# sourceMappingURL=NodeConsoleLedgerService.js.map