"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedisNodeConsoleRepository = void 0;
const node_util_1 = require("node:util");
const redis_1 = require("@jfrog-pipelines/redis");
const utility_1 = require("@jfrog-pipelines/utility");
const logger_1 = require("@jfrog-pipelines/logger");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const NodeConsoleDao_1 = require("../../../driven/db/NodeConsoleDao");
const NodeDao_1 = require("../../../driven/db/NodeDao");
class RedisNodeConsoleRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('NodeConsoleCache');
        this.cacheClient = redis_1.RedisClientFactory.client;
        this.nodeConsoleDao = new NodeConsoleDao_1.NodeConsoleDao();
        this.nodeDao = new NodeDao_1.NodeDao();
    }
    async create(nodeConsole) {
        const node = await this.getNodeFromNodeId(nodeConsole.nodeId);
        if (!node) {
            return {};
        }
        const key = this.getRedisKey(nodeConsole.nodeId);
        await this.cacheClient.client.lpush(key, Buffer.from((0, utility_1.encode)(nodeConsole)));
        return nodeConsole;
    }
    async createBulk(nodeConsoles) {
        if (nodeConsoles.length < 0) {
            return [];
        }
        const node = await this.getNodeFromNodeId(nodeConsoles[0].nodeId);
        if (!node) {
            return [];
        }
        const key = this.getRedisKey(nodeConsoles[0].nodeId);
        const bufferedConsoles = nodeConsoles.map((nodeConsole) => Buffer.from((0, utility_1.encode)(nodeConsole)));
        await this.cacheClient.client.rpush(key, ...bufferedConsoles);
        return nodeConsoles;
    }
    async getById(nodeId) {
        const key = this.getRedisKey(nodeId);
        const records = await this.cacheClient.client.lrangeBuffer(key, 0, -1);
        const nodeConsoles = [];
        records.map((record) => {
            try {
                nodeConsoles.push((0, utility_1.decode)(record));
            }
            catch (error) {
                this.logger.warn(`${(0, node_util_1.inspect)(error)}`);
            }
        });
        const usage = await this.cacheClient.client.memory('USAGE', key);
        this.logger.info(`console usage in redis for nodeId ${nodeId} = ${(0, node_util_1.inspect)(usage)}`);
        return nodeConsoles;
    }
    async deleteByNodeId(nodeId) {
        const key = this.getRedisKey(nodeId);
        await this.cacheClient.client.del([key]);
        try {
            this.logger.info(`Deleting consoles from database for migration purpose for nodeId ${nodeId} of nodepoolId ${nodeId}`);
            const query = new data_access_layer_1.SequelizeQueryBuilder({}).where('nodeId', nodeId).build();
            await this.nodeConsoleDao.delete(query);
        }
        catch (error) {
            this.logger.warn(`Failed to delete logs from database for nodeId ${nodeId} due to error ${(0, node_util_1.inspect)(error)}`);
        }
    }
    getNodeFromNodeId(nodeId) {
        return this.nodeDao.findById(nodeId);
    }
    getRedisKey(nodeId) {
        return `node:${nodeId}:consoles`;
    }
}
exports.RedisNodeConsoleRepository = RedisNodeConsoleRepository;
//# sourceMappingURL=RedisNodeConsoleRepository.js.map