"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StatsDomainService = void 0;
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const sortOrderForSequelize_1 = require("../../shared/sortOrderForSequelize");
const NodeStatsDao_1 = require("../../driven/db/NodeStatsDao");
class StatsDomainService {
    constructor() {
        this.nodeStatsDao = new NodeStatsDao_1.NodeStatsDao();
    }
    async create(nodeId, nodeStats) {
        const newNodeStat = {
            nodeId,
            reportedAt: new Date(nodeStats.reportedAt),
            diskUsageInPercentage: nodeStats.diskUsageInPercentage,
            memoryUsageInPercentage: nodeStats.memoryUsageInPercentage,
            cpuLoadInPercentage: nodeStats.cpuLoadInPercentage,
            activeContainersCount: nodeStats.activeContainersCount,
            totalContainersCount: nodeStats.totalContainersCount,
            imageCount: nodeStats.imageCount
        };
        await this.nodeStatsDao.create(newNodeStat);
    }
    async getAll(nodeId, query) {
        const queryObject = this.createGetQuery(nodeId, query);
        const result = await this.nodeStatsDao.findAll(queryObject);
        return result.map((value) => {
            return {
                ...value.toJSON(),
                reportedAt: value.reportedAt.toISOString()
            };
        });
    }
    async deleteNodeStats(reportedBefore) {
        const query = new data_access_layer_1.SequelizeQueryBuilder({})
            .whereWithOperator('reportedAt', reportedBefore, data_access_layer_1.operatorsKey.$lt)
            .build();
        return this.nodeStatsDao.delete(query);
    }
    async deleteByNodeId(nodeId) {
        const query = new data_access_layer_1.SequelizeQueryBuilder({}).where('nodeId', nodeId).build();
        return this.nodeStatsDao.delete(query);
    }
    async getLatestNodeStatForNode(nodeId) {
        const queryObject = {
            limit: 1,
            sortBy: 'reportedAt',
            sortOrder: 'DESC'
        };
        const getNodeStatsQuery = new data_access_layer_1.SequelizeQueryBuilder(queryObject).where('nodeId', nodeId).sort().limit().build();
        return this.nodeStatsDao.findOne(getNodeStatsQuery);
    }
    createGetQuery(nodeId, query) {
        const queryObject = {
            limit: query.limit,
            sortBy: query.sort ?? 'reportedAt',
            sortOrder: (0, sortOrderForSequelize_1.getSortOrderForSequelize)(query.order)
        };
        const queryBuilder = new data_access_layer_1.SequelizeQueryBuilder(queryObject)
            .where('nodeId', nodeId)
            .limit()
            .offset(query.skip)
            .sort();
        if (query.reported_after) {
            queryBuilder.whereWithOperator('reportedAt', query.reported_after, data_access_layer_1.operatorsKey.$gt);
        }
        if (query.reported_before) {
            queryBuilder.whereWithOperator('reportedAt', query.reported_before, data_access_layer_1.operatorsKey.$lt);
        }
        return queryBuilder.build();
    }
}
exports.StatsDomainService = StatsDomainService;
//# sourceMappingURL=StatsDomainService.js.map