"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cloud_1 = require("@jfrog-pipelines/cloud");
const CloudServiceClient_1 = require("../CloudServiceClient");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: {
            config: {
                getCustom: (key) => {
                    if (key === 'runtime.saasEnvironment') {
                        return 'development';
                    }
                    if (key === 'runtime.saasCustomerName') {
                        return 'customer';
                    }
                    if (key === 'runtime.isSaas') {
                        return 'true';
                    }
                }
            }
        }
    };
});
jest.mock('@jfrog-pipelines/cloud');
jest.mock('../../../../driven/acl/userService', () => {
    return {
        UserRepository: jest.fn().mockReturnValue({
            getProjectIntegrationById: jest.fn().mockImplementation((id) => {
                if (id === 'integrationId') {
                    return {
                        formJSONValues: [{ label: 'key', value: 'value' }],
                        masterIntegrationName: 'amazonKeys'
                    };
                }
                return {
                    formJSONValues: [{ label: 'key', value: 'value' }],
                    masterIntegrationName: 'invalidProvider'
                };
            })
        })
    };
});
describe('CloudServiceClient', () => {
    const cloudServiceClient = new CloudServiceClient_1.CloudServiceClient();
    describe('getNodeProvider', () => {
        it('should return a CloudProvider based on the project integration', async () => {
            const node = {
                projectIntegrationId: 'integrationId',
                id: 1
            };
            const getProviderSpy = jest.spyOn(cloud_1.CloudFactory, 'getProvider');
            await cloudServiceClient.getNodeProvider(node);
            expect(getProviderSpy).toHaveBeenCalledWith('aws', { key: 'value' }, expect.anything());
            expect(cloud_1.InstanceVariables).toHaveBeenCalledTimes(1);
        });
        it('should throw an error for an invalid provider name', async () => {
            const node = {
                projectIntegrationId: 1
            };
            await expect(cloudServiceClient.getNodeProvider(node)).rejects.toThrow('Invalid provider name: undefined');
        });
    });
});
//# sourceMappingURL=CloudServiceClient.test.js.map