"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const MachineImageService_1 = require("../../../machine-image/MachineImageService");
const K8sRequestTransformer_1 = require("../K8sRequestTransformer");
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn(),
            getEventLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            })
        }
    };
});
const nodePoolerIdleInterval = 1000;
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: {
            config: {
                runMode: 'dev',
                nodePollerIntervalMS: 15000,
                customCertsEnabled: false,
                noVerifySsl: false,
                getCustom: jest.fn()
            }
        }
    };
});
jest.mock('../../../../driven/acl/userService', () => {
    return {
        UserRepository: jest.fn().mockReturnValue({
            getUnifiedUiAndWwwUrl: jest
                .fn()
                .mockResolvedValue({ wwwUrl: 'http://localhost/wwwUrl', rtUiUrl: 'http://localhost/rtUiUrl' }),
            getProjectById: jest.fn().mockImplementation((id) => ({ id, name: 'projectName' }))
        })
    };
});
describe('K8s request transformer', () => {
    const k8sTransformer = new K8sRequestTransformer_1.K8sRequestTransformer('dev', 'testexternal', nodePoolerIdleInterval, false, '');
    describe('getNodeCreateRequest', () => {
        it('should return valid request for k8s clinet', async () => {
            jest
                .spyOn(MachineImageService_1.MachineImageService.prototype, 'getBuildPlaneImageById')
                .mockResolvedValueOnce({ imageId: '1' });
            const nodePool = {
                id: 1,
                buildPlaneImageId: 1,
                projectId: 1,
                projectIntegrationId: 1,
                name: 'nodePoolName',
                operatingSystem: 'Ubuntu_18.04',
                architecture: 'x86_64',
                providerMetadataPropertyBag: {},
                initPropertyBag: {}
            };
            const node = {
                id: 1,
                friendlyName: 'nodeFriendlyName',
                providerMetadataPropertyBag: {
                    imageId: 'testImageId'
                },
                systemPropertyBag: {
                    token: 'testtoken'
                }
            };
            const createdRequest = await k8sTransformer.getNodeCreateRequest(nodePool, node);
            expect(createdRequest.getK8sConfig).toBeDefined();
        });
    });
    describe('getNodeDeleteRequest', () => {
        it('should get valid delete request for deployment', () => {
            const node = {
                id: 1,
                friendlyName: 'nodeFriendlyName',
                systemPropertyBag: {},
                providerMetadataPropertyBag: {
                    imageId: 'testImageId'
                }
            };
            const deleteRequest = k8sTransformer.getNodeDeleteRequest(node);
            expect(deleteRequest.getNameSpace()).toBe('default');
        });
    });
    describe('getNodeTransitionRequest', () => {
        it('should get valid transition request', () => {
            const node = {
                id: 1,
                friendlyName: 'nodeFriendlyName',
                systemPropertyBag: {},
                providerMetadataPropertyBag: {
                    imageId: 'testImageId'
                }
            };
            const transitionRequest = k8sTransformer.getNodeTransitionRequest(node);
            expect(transitionRequest.getNameSpace()).toBe('default');
        });
    });
});
//# sourceMappingURL=K8sRequestTransformer.test.js.map