{{#if (eq operatingSystem 'WindowsServer_2019') }}
$ErrorActionPreference = "Stop"

if (!"$JFROG_DIR") {
  New-Variable -Name JFROG_DIR -Scope Global -Option ReadOnly -Value "$env:PROGRAMDATA\jfrog\pipelines" -Force
}

New-Variable -Name REQKICK_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\reqKick" -Force
New-Variable -Name EXECTEMPLATES_DIR -Scope Global -Option ReadOnly -Value "$REQKICK_DIR\node_modules\@jfrog-pipelines/core\execTemplates" -Force
New-Variable -Name EXTENSIONS_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\extensions" -Force
New-Variable -Name REQEXEC_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\reqExec" -Force
New-Variable -Name REPORTS_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\reports" -Force
New-Variable -Name NODEINIT_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\nodeInit" -Force
New-Variable -Name REQKICK_SERVICE_NAME -Scope Global -Option ReadOnly -Value "pipelines-reqKick" -Force
New-Variable -Name CUSTOM_CERTS_DIR -Scope Global -Option ReadOnly -Value "$JFROG_DIR\var\etc\security\keys\trusted" -Force

New-Variable -Name BUILDPLANE_TAR_DOWNLOAD_URL -Scope Global -Value "{{buildPlaneArtifactDownloadUrl}}" -Force
New-Variable -Name NODE_OPERATING_SYSTEM -Scope Global -Value "{{operatingSystem}}" -Force
New-Variable -Name NODE_ARCHITECTURE -Scope Global -Value "{{architecture}}" -Force
New-Variable -Name RUN_MODE -Scope Global -Value "{{runMode}}" -Force
New-Variable -Name NODE_ID -Scope Global -Value "{{nodeId}}" -Force
New-Variable -Name PROJECT_ID -Scope Global -Value "{{projectId}}" -Force
New-Variable -Name BUILD_PLANE_VERSION -Scope Global -Value "{{buildPlaneVersion}}" -Force
New-Variable -Name PIPELINES_SHARED_ARTIFACTORY_BASEURLUI -Scope Global -Value "{{baseUrlUI}}" -Force
New-Variable -Name PIPELINES_CORE_SERVICES_API_EXTERNALURL -Scope Global -Value "{{apiUrl}}" -Force
New-Variable -Name INSECURE_DOCKER_REGISTRIES -Scope Global -Value '{{insecureDockerRegistries}}' -Force

New-Variable -Name PIPELINES_CORE_PROXY_HTTPPROXY -Scope Global -Value "{{httpProxy}}" -Force
New-Variable -Name PIPELINES_CORE_PROXY_HTTPSPROXY -Scope Global -Value "{{httpsProxy}}" -Force
New-Variable -Name PIPELINES_CORE_PROXY_NOPROXY -Scope Global -Value "{{noProxy}}" -Force
New-Variable -Name BOOT_BUILD_AGENT -Scope Global -Value $TRUE -Force
New-Variable -Name CONFIGURE_NODE -Scope Global -Value {{configureNode}} -Force
New-Variable -Name NO_VERIFY_SSL -Scope Global -Value {{noVerifySsl}} -Force
New-Variable -Name PIPELINES_NODE_API_TOKEN -Scope Global -Value "{{token}}" -Force
New-Variable -Name NODE_POLLER_INTERVAL_MS -Scope Global -Value  {{nodePollerIntervalMS}} -Force
New-Variable -Name CUSTOM_CERTS_ENABLED -Scope Global -Value {{customCertsEnabled}} -Force

if ($CUSTOM_CERTS_ENABLED -eq "true") {
  New-Variable -Name CUSTOM_CERTS_DATA -Scope Global -Value {{customCertsData}} -Force
} else {
  New-Variable -Name CUSTOM_CERTS_DATA -Scope Global -Value "" -Force
}

$headers = @{}
$headers['Authorization'] = "Bearer $PIPELINES_NODE_API_TOKEN"

if ($CONFIGURE_NODE -eq "true") {
  Set-Variable -Name CONFIGURE_NODE -Value $TRUE -Force
} else {
  Set-Variable -Name CONFIGURE_NODE -Value $FALSE -Force
}

if ($NO_VERIFY_SSL -eq "true") {
  Set-Variable -Name NO_VERIFY_SSL -Value $TRUE -Force

  if (-not ([System.Management.Automation.PSTypeName]"TrustEverything").Type) {
    Add-Type -TypeDefinition  @"
using System.Net.Security;
using System.Security.Cryptography.X509Certificates;
public static class TrustEverything
{
  private static bool ValidationCallback(object sender, X509Certificate certificate, X509Chain chain,
    SslPolicyErrors sslPolicyErrors) { return true; }
  public static void SetCallback() { System.Net.ServicePointManager.ServerCertificateValidationCallback = ValidationCallback; }
  public static void UnsetCallback() { System.Net.ServicePointManager.ServerCertificateValidationCallback = null; }
}
"@
  }
  [TrustEverything]::SetCallback()
} else {
  Set-Variable -Name NO_VERIFY_SSL -Value $FALSE -Force
}

if ($CUSTOM_CERTS_ENABLED -eq "true") {
  Set-Variable -Name CUSTOM_CERTS_ENABLED -Value $TRUE -Force
  New-Item "$CUSTOM_CERTS_DIR" -ItemType Directory -Force
  echo $CUSTOM_CERTS_DATA.replace("\n", "`n") | Out-File -Encoding utf8 "$CUSTOM_CERTS_DIR\ca.crt"

  # In windows, we can add cert one by one. Hence splitting the files to
  # individual cert files.
  $Pattern = "(?smi)^-{2,}BEGIN CERTIFICATE-{2,}.*?-{2,}END CERTIFICATE-{2,}"
  Get-Content "$CUSTOM_CERTS_DIR\ca.crt" -raw |
    Select-String  -Pattern $Pattern -Allmatches|
      ForEach-Object {$Cnt=0;$_.Matches}| ForEach-Object {
        $Cnt++
        Set-Content -Value $_.Value -Path ("$CUSTOM_CERTS_DIR\ca{0}.crt" -f $Cnt)
      }
  Remove-Item "$CUSTOM_CERTS_DIR\ca.crt"
  $Files = Get-ChildItem $CUSTOM_CERTS_DIR
  foreach ($F in $Files) {
    certutil -addstore -f "ROOT" "$CUSTOM_CERTS_DIR\$F"
  }
} else {
  Set-Variable -Name CUSTOM_CERTS_ENABLED -Value $FALSE -Force
}

# Reqkick uses an npm package win-ca to establish trust. win-ca
# creates a file in node modules, which can't be removed if reqkick
# is running. So before untaring the BP and it replaces the existing
# BP when re-init, we check if reqkick service is running and if yes,
# stop the service
if (Get-Command "nssm" -ErrorAction SilentlyContinue) {
  Get-Service pipelines-reqKick -ErrorAction SilentlyContinue | %{
    if ($_.Status -eq "Running") {
      nssm stop $_.Name
    }
  }
}

Invoke-Webrequest -Headers $headers -Uri $BUILDPLANE_TAR_DOWNLOAD_URL -Outfile buildPlane.tar.gz

if (Test-Path "$env:PROGRAMDATA\jfrog\pipelines") {
  Remove-Item "$env:PROGRAMDATA\jfrog\pipelines" -Recurse;
}
New-Item -ItemType directory -path "$env:PROGRAMDATA\jfrog\pipelines" -Force
tar -xf buildPlane.tar.gz -C "$env:PROGRAMDATA\jfrog\pipelines"

. $NODEINIT_DIR/$NODE_ARCHITECTURE/$NODE_OPERATING_SYSTEM/boot.ps1


$Jsonbody= @{
    'lastInitializedAt' =  Get-Date -Format yyyy-MM-ddTHH:mm:ssZ
    } | ConvertTo-Json

try {
    $Response = Invoke-RestMethod -Method Put -Headers $headers -ContentType 'application/json' -Uri "$PIPELINES_CORE_SERVICES_API_EXTERNALURL/nodes/$NODE_ID" -Body $Jsonbody -ErrorAction Stop
    $StatusCode = $Response.StatusCode
}
catch{
    $StatusCode = $Response
}
{{/if}}