"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepRepository = void 0;
const microservice_1 = require("@jfrog-pipelines/microservice");
const metadata_1 = require("@jfrog-pipelines/metadata");
const StepDataAdapterFactory_1 = require("./StepDataAdapterFactory");
class StepRepository {
    constructor() {
        this.adapter = StepDataAdapterFactory_1.StepDataAdapterFactory.create(microservice_1.AclAdapterDi.api);
    }
    async resetBuildPlaneByNodeId(nodeId) {
        const queryString = `nodeIds=${nodeId}&statusCodes=${metadata_1.READY},${metadata_1.QUEUED}`;
        const messages = await this.adapter.getBuildPlaneMessages(queryString);
        if (messages.length === 0) {
            throw new Error(`Could not find buildPlane message by ${queryString}`);
        }
        const buildPlaneMessage = messages[0];
        const update = {
            resetBuildPlaneMessage: true,
            nodeId: nodeId
        };
        await this.adapter.putBuildPlaneMessageById(buildPlaneMessage.id, update);
    }
    getStepById(stepId) {
        return this.adapter.getStepById(stepId);
    }
    getStepsQueuedToTheNode(affinityGroup, runId) {
        return this.adapter.getStepsQueuedToTheNode(affinityGroup, runId);
    }
    timeOutSteps(steps) {
        return this.adapter.timeOutSteps(steps);
    }
    postMessageToStepConsole(groupName, cmdName, message, stepId, pipelineId) {
        return this.adapter.postMessageToStepConsole(groupName, cmdName, message, stepId, pipelineId);
    }
}
exports.StepRepository = StepRepository;
//# sourceMappingURL=StepRepository.js.map