"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const internal_clients_1 = require("@jfrog-pipelines/internal-clients");
const metadata_1 = require("@jfrog-pipelines/metadata");
const ApiStepDataAdapter_1 = require("../ApiStepDataAdapter");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'testtoken' } }
    };
});
jest.mock('@jfrog-pipelines//internal-clients');
const stepId = 1;
const stepMock = {
    id: stepId,
    isConsoleArchived: true
};
describe('ApiStepDataAdapter', () => {
    describe('getBuildPlaneMessages', () => {
        it('should return an array of BuildPlaneMessageAttributes', async () => {
            const nodeId = 123;
            const adapter = new ApiStepDataAdapter_1.ApiStepDataAdapter();
            const expectedResponse = [
                {
                    id: 1,
                    nodeId: 123,
                    projectId: 1,
                    nodePoolId: 1,
                    statusCode: metadata_1.READY
                }
            ];
            jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getBuildPlaneMessages').mockResolvedValueOnce(expectedResponse);
            const queryString = `nodeIds=${nodeId}&statusCodes=${metadata_1.READY},${metadata_1.QUEUED}`;
            const messages = await adapter.getBuildPlaneMessages(queryString);
            expect(messages.length).toBeGreaterThan(0);
            expect(internal_clients_1.PipelinesClient.prototype.getBuildPlaneMessages).toHaveBeenCalledWith(queryString);
        });
    });
    describe('putBuildPlaneMessageById', () => {
        it('should return a BuildPlaneMessageAttributes', async () => {
            const adapter = new ApiStepDataAdapter_1.ApiStepDataAdapter();
            const nodeId = 123;
            const expectedResponse = {
                id: 1,
                projectId: 1,
                statusCode: metadata_1.READY
            };
            jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'putBuildPlaneMessageById').mockResolvedValueOnce(expectedResponse);
            await adapter.putBuildPlaneMessageById(nodeId, {
                resetBuildPlaneMessage: true,
                nodeId: nodeId
            });
            expect(internal_clients_1.PipelinesClient.prototype.putBuildPlaneMessageById).toHaveBeenCalledWith(nodeId, {
                resetBuildPlaneMessage: true,
                nodeId: nodeId
            });
        });
    });
});
describe('Step Adapter', () => {
    const adapter = new ApiStepDataAdapter_1.ApiStepDataAdapter();
    it('should return step from given id', async () => {
        const getStepByIdSpy = jest
            .spyOn(internal_clients_1.PipelinesClient.prototype, 'getStepById')
            .mockResolvedValue(stepMock);
        const step = await adapter.getStepById(stepId);
        expect(getStepByIdSpy).toHaveBeenCalledTimes(1);
        expect(getStepByIdSpy).toHaveBeenCalledWith(stepId);
        expect(step).toEqual(stepMock);
    });
    it('should call pipelines client getSteps for queued nodes', async () => {
        const affinityGroup = 'affinity';
        const runId = 1;
        const statusCodes = '4005,4001,4000,4013,4014';
        const query = `affinityGroups=${affinityGroup}&runIds=${runId}&statusCodes=${statusCodes}`;
        const getStepsSpy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'getSteps');
        await adapter.getStepsQueuedToTheNode(affinityGroup, runId);
        expect(getStepsSpy).toHaveBeenCalledTimes(1);
        expect(getStepsSpy).toHaveBeenCalledWith(query);
    });
    it('should timeout steps', async () => {
        const stepInput = {
            id: stepId,
            statusCode: 4001
        };
        const stepOutput = {
            id: stepId,
            statusCode: 4009
        };
        const updateQuery = {
            statusCode: 4009
        };
        const updateStepSpy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'updateStep').mockResolvedValueOnce(stepOutput);
        await adapter.timeOutSteps([stepInput]);
        expect(updateStepSpy).toHaveBeenCalledTimes(1);
        expect(updateStepSpy).toHaveBeenCalledWith(stepId, updateQuery);
    });
});
describe('Step Console Adapter', () => {
    const pipelineId = 1;
    const groupName = 'group';
    const cmdName = 'cmd';
    const message = 'message';
    const stepId = 1;
    it('should post message to step console', async () => {
        const adapter = new ApiStepDataAdapter_1.ApiStepDataAdapter();
        const openGroupSpy = jest.spyOn(internal_clients_1.PipelinesClient.prototype, 'postStepConsoles').mockImplementation(jest.fn());
        await adapter.postMessageToStepConsole(groupName, cmdName, message, stepId, pipelineId);
        expect(openGroupSpy).toHaveBeenCalledTimes(5);
    });
});
//# sourceMappingURL=ApiStepDataAdapter.test.js.map