"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserRepository = void 0;
const microservice_1 = require("@jfrog-pipelines/microservice");
const logger_1 = require("@jfrog-pipelines/logger");
const cache_1 = require("@jfrog-pipelines/cache");
const UserDataAdapterFactory_1 = require("./UserDataAdapterFactory");
const UNIFIED_URL_TTL_1_HOUR_IN_MS = 3600000;
const PROJECT_TTL_1_DAY_IN_MS = 86400000;
const PROJECT_INTEGRATION_TTL_15_MIN_IN_MS = 900000;
class UserRepository {
    constructor() {
        this.logger = logger_1.LoggerFactory.getLogger('UserRepository');
        this.adapter = UserDataAdapterFactory_1.UserDataAdapterFactory.create(microservice_1.AclAdapterDi.api);
        this.cache = cache_1.CacheStoreFactory.getCache("MEMORY");
    }
    async getProjectById(id) {
        const cacheKey = `project-${id}`;
        const data = await this.getCacheData(cacheKey);
        if (data) {
            this.logger.trace(`${cacheKey} served from cache`);
            return data;
        }
        const result = await this.adapter.getProjectById(id);
        await this.cache.set(cacheKey, result, PROJECT_TTL_1_DAY_IN_MS);
        return result;
    }
    async getProjectIntegrationById(id) {
        const cacheKey = `projectIntegration-${id}`;
        const data = await this.getCacheData(cacheKey);
        if (data) {
            this.logger.trace(`${cacheKey} served from cache`);
            return data;
        }
        const result = await this.adapter.getProjectIntegrationById(id);
        await this.cache.set(cacheKey, result, PROJECT_INTEGRATION_TTL_15_MIN_IN_MS);
        return result;
    }
    getUnifiedUiAndWwwUrl() {
        return this.adapter.getUnifiedUiAndWwwUrl();
    }
    async getCacheData(cacheKey) {
        try {
            return await this.cache.get(cacheKey);
        }
        catch {
            return null;
        }
    }
}
__decorate([
    (0, cache_1.cacheable)({ key: 'unifieduiurl', ttl: UNIFIED_URL_TTL_1_HOUR_IN_MS }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], UserRepository.prototype, "getUnifiedUiAndWwwUrl", null);
exports.UserRepository = UserRepository;
//# sourceMappingURL=UserRepository.js.map