"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ServerDefinitionV1 = void 0;
const http_server_1 = require("@jfrog-pipelines/http-server");
const types_1 = require("@jfrog-pipelines/types");
const configuration_1 = require("@jfrog-pipelines/configuration");
const NodeV1Route_1 = require("./node/NodeV1Route");
const MachineImageV1Route_1 = require("./machine-image/MachineImageV1Route");
class ServerDefinitionV1 {
    constructor(serviceInformation) {
        this.serviceInformation = serviceInformation;
        this.description = 'NodePool Microservice open apis 3';
        this.version = '1.0.0';
        this.serverPrefix = 'api/v1';
    }
    getDocumentation() {
        return new http_server_1.DocumentationVo(this.serviceInformation.name, this.description, this.version);
    }
    getServerPrefix() {
        return this.serverPrefix;
    }
    getRoutes(httpServer) {
        const routes = [new NodeV1Route_1.NodeV1Route(), new MachineImageV1Route_1.MachineImageV1Route()];
        routes.map((route) => {
            route.register(httpServer);
        });
    }
    getReuseableSchema() {
        return [types_1.NodeStatsResponseSchema, types_1.NodeConsoleResponseSchema, types_1.MachineImageResponseSchema];
    }
    getHttpPort() {
        return configuration_1.ConfigFactory.config.nodePoolServiceServicePort;
    }
    getName() {
        return this.serviceInformation.name;
    }
    getRouterUrl() {
        return `http://localhost:${configuration_1.ConfigFactory.config.rtRouterAccessPort}`;
    }
}
exports.ServerDefinitionV1 = ServerDefinitionV1;
//# sourceMappingURL=ServerDefinitionV1.js.map