"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MachineImageDeleteById = exports.MachineImagePatch = exports.MachineImagePost = exports.MachineImageGetAll = exports.MachineImageGetById = void 0;
const types_1 = require("@jfrog-pipelines/types");
exports.MachineImageGetById = {
    tags: ['MachineImages'],
    description: 'Get machine image by id',
    params: types_1.MachineImageIdParameter,
    querystring: types_1.MachineImageQuerySchema,
    response: {
        200: {
            description: 'Get Machine Image By Id',
            content: {
                'application/json': {
                    schema: types_1.MachineImageResponseReference
                }
            }
        },
        403: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image get is not allowed'
        },
        404: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image was not found'
        },
        500: {
            description: 'Internal Server Error',
            content: {
                'application/json': {
                    schema: types_1.ErrorSchema
                }
            }
        }
    }
};
exports.MachineImageGetAll = {
    tags: ['MachineImages'],
    description: 'Get machine image by id',
    querystring: types_1.MachineImageQuerySchema,
    response: {
        200: {
            description: 'Get machine image by Id',
            content: {
                'application/json': {
                    schema: {
                        type: 'array',
                        items: types_1.MachineImageResponseReference
                    }
                }
            }
        },
        500: {
            description: 'Internal Server Error',
            content: {
                'application/json': {
                    schema: types_1.ErrorSchema
                }
            }
        }
    }
};
exports.MachineImagePost = {
    tags: ['MachineImages'],
    description: 'Create a new machine image for cloud machines',
    body: types_1.MachineImageRequestSchema,
    response: {
        200: types_1.MachineImageResponseSchema,
        400: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Bad Request for machine image creation'
        },
        403: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image creation is not allowed'
        },
        409: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image update failed'
        },
        500: {
            description: 'Internal Server Error',
            content: {
                'application/json': {
                    schema: types_1.ErrorSchema
                }
            }
        }
    }
};
exports.MachineImagePatch = {
    tags: ['MachineImages'],
    description: 'Update a existing machine image for cloud machines',
    params: types_1.MachineImageIdParameter,
    body: types_1.MachineImageUpdateSchema,
    response: {
        200: types_1.MachineImageResponseSchema,
        400: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Bad Request for machine image update'
        },
        403: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image update is not allowed'
        },
        404: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image was not found for update'
        },
        409: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Machine image update failed'
        },
        500: {
            description: 'Internal Server Error',
            content: {
                'application/json': {
                    schema: types_1.ErrorSchema
                }
            }
        }
    }
};
exports.MachineImageDeleteById = {
    tags: ['MachineImages'],
    description: 'Deletes an existing machine image for cloud machines',
    params: types_1.MachineImageIdParameter,
    response: {
        204: { type: 'object', properties: {}, description: 'The machine image was deleted' },
        400: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'Bad Request for machine image deletion'
        },
        404: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'machine image not found'
        },
        403: {
            type: 'object',
            properties: {
                message: {
                    type: 'string'
                }
            },
            description: 'machine image deletion not allowed'
        },
        500: {
            description: 'Internal Server Error',
            content: {
                'application/json': {
                    schema: types_1.ErrorSchema
                }
            }
        }
    }
};
//# sourceMappingURL=MachineImageSchema.js.map