"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureAwareFactory = void 0;
const JobDomainService_1 = require("../domain/job/JobDomainService");
const featureFlag_1 = require("./featureFlag");
const STANDBY_NODE_COUNT = 1;
class FeatureAwareFactory {
    constructor() {
        this.buildPlaneService = new JobDomainService_1.JobDomainService();
        this.features = new featureFlag_1.FeatureFlag();
    }
    async getRequiredNodes(nodePoolId) {
        const isHotNodePoolEnabled = await this.features.isHotNodePoolEnabled();
        if (!isHotNodePoolEnabled) {
            return this.getNodeCount(nodePoolId);
        }
        return this.getNodeCountWithStandByNode(nodePoolId);
    }
    async getNodeCount(nodePoolId) {
        return this.buildPlaneService.getReadyMessageCount(nodePoolId);
    }
    async getNodeCountWithStandByNode(nodePoolId) {
        const requiredNodes = await this.buildPlaneService.getReadyMessageCount(nodePoolId);
        return requiredNodes + STANDBY_NODE_COUNT;
    }
}
exports.FeatureAwareFactory = FeatureAwareFactory;
//# sourceMappingURL=FeatureAwareFactory.js.map